Struct build_script::instruction::Instruction[][src]

pub struct Instruction {
    pub prefix: Prefix,
    pub name: Option<String>,
    pub value: Value,
}

An instruction. Used as a rusty way to parse arguments in build scripts.

Fields

prefix: Prefix

The prefix. Usually Cargo.

name: Option<String>

The name of the instruction. Most of the time it’s filled in, only when a new mapping new_mapping() is created it’s not.

value: Value

The Value of the Instruction.

Implementations

impl Instruction[src]

pub fn new(name: &str, value: Value) -> Self[src]

Create a new Instruction. 99% of the time this should suffice instead of new_mapping().

pub fn new_mapping(value: Value) -> Self[src]

Create a new Instruction Mapping. Only 1% of the time is this proven useful, instead use new().

Panics

This panics if value is not a Mapping or UnquotedMapping.

pub fn prefix(&mut self, prefix: Prefix) -> &mut Self[src]

Set the prefix.

pub fn name(&mut self, name: &str) -> &mut Self[src]

Set the name.